esp_provisioning_state library
Classes
- EspProvisioningState
- EspProvisioningState is a class that contains a bunch of properties that are used to store the state of the ESP provisioning
Enums
- EspProvisioningFailure
- A typed reason for a failed provisioning action.
- EspProvisioningStatus
- A list of all the possible states that the ESP provisioning can be in